@@ -92,9 +92,8 @@ def get_tf_prediction_ds(adata, batch_size=1000):
 
     return dataset
 
-def process_from_counts(adata, min_genes=200, min_cells=3, mito_threshold=.2, max_n_genes=None,
-        log=True, cpm=True, min_disp=.2, standard_scaler=None, range_scaler=None,
-        normalize_samples=True):
+def process_from_counts(adata, min_genes=None, min_cells=None,
+        log=True, standard_scaler=None, range_scaler=None):
     if min_genes is not None:
         logging.info(f'filtering by min genes: {min_genes}')
         sc.pp.filter_cells(adata, min_genes=min_genes)
@@ -104,41 +103,11 @@ def process_from_counts(adata, min_genes=200, min_cells=3, mito_threshold=.2, ma
         sc.pp.filter_genes(adata, min_cells=min_cells)
         logging.info(f'genes remaining after filter: {adata.shape[1]}')
 
-    if mito_threshold is not None or max_n_genes is not None: 
-        logging.info('calculating MT and gene counts')
-        mito_genes = adata.var_names.str.startswith('MT-')
-        if 'sparse' in str(type(adata.X)).lower():
-            adata.obs['percent_mito'] = np.sum(
-                adata[:, mito_genes].X, axis=1).A1 / np.sum(adata.X, axis=1).A1
-            adata.obs['n_counts'] = adata.X.sum(axis=1).A1
-        else:
-            adata.obs['percent_mito'] = np.sum(
-                adata[:, mito_genes].X, axis=1) / np.sum(adata.X, axis=1)
-            # add the total counts per cell as observations-annotation to adata
-            adata.obs['n_counts'] = adata.X.sum(axis=1)
-    
-        if mito_threshold is not None:
-            logging.info('filtering by mito threshold')
-            adata = adata[adata.obs.percent_mito < mito_threshold, :]
-        if max_n_genes is not None:
-            logging.info('filtering by n genes threshold')
-            adata = adata[adata.obs.n_genes < max_n_genes, :]
-
     if log:
-        logging.info('loging data')
         sc.pp.log1p(adata)
     adata.raw = adata
     
-    if min_disp is not None:
-        logging.info(f'filtering with dispersion {min_disp}')
-        sc.pp.highly_variable_genes(adata, min_mean=None, max_mean=None, min_disp=min_disp)
-        remaining = np.count_nonzero(adata.var.highly_variable)
-        logging.info(f'remaining after min disp: {remaining}')
-        adata = adata[:, adata.var.highly_variable]
-
-
     logging.info('scaling data')
-
     if standard_scaler is None:
         standard_scaler = StandardScaler(with_mean=False, with_std=True)
         adata.X = standard_scaler.fit_transform(adata.X)
@@ -178,9 +147,9 @@ def filter_adata_genes(adata, genes):
     return new_adata[:, genes]
 
 class PollockDataset(object):
-    def __init__(self, adata, cell_type_key='ClusterName', n_per_cell_type=500,
-            batch_size=64, dataset_type='training', min_genes=10, min_cells=3, mito_threshold=None,
-            max_n_genes=None, log=True, cpm=False, min_disp=None, standard_scaler=None,
+    def __init__(self, adata, cell_type_key='cell_type', n_per_cell_type=500,
+            batch_size=64, dataset_type='training', min_genes=None, min_cells=None,
+            log=True, standard_scaler=None,
             range_scaler=None, cell_type_encoder=None, genes=None, cell_types=None):
 
         self.adata = adata
@@ -189,11 +158,7 @@ class PollockDataset(object):
         self.cell_types = cell_types
         self.min_genes = min_genes
         self.min_cells = min_cells
-        self.mito_threshold = mito_threshold
-        self.max_n_genes = max_n_genes
         self.log = log
-        self.cpm = cpm
-        self.min_disp = min_disp
         self.standard_scaler = standard_scaler
         self.range_scaler = range_scaler
         self.cell_type_encoder = cell_type_encoder
@@ -219,8 +184,7 @@ class PollockDataset(object):
         """"""
         logging.info(f'normalizing counts for model training')
         self.adata, self.standard_scaler, self.range_scaler = process_from_counts(self.adata,
-                min_genes=self.min_genes, min_cells=self.min_cells, mito_threshold=self.mito_threshold,
-                max_n_genes=self.max_n_genes, log=self.log, cpm=self.cpm, min_disp=self.min_disp,
+                min_genes=self.min_genes, min_cells=self.min_cells, log=self.log,
                 standard_scaler=self.standard_scaler, range_scaler=self.range_scaler)
         self.genes = np.asarray(self.adata.var.index)
 
@@ -243,12 +207,11 @@ class PollockDataset(object):
         logging.info(f'normalizing counts for prediction')
         self.prediction_adata = filter_adata_genes(self.adata, self.genes)
         self.prediction_adata, _, _ = process_from_counts(self.prediction_adata,
-                min_genes=self.min_genes, min_cells=self.min_cells, mito_threshold=self.mito_threshold,
-                max_n_genes=self.max_n_genes, log=self.log, cpm=self.cpm, min_disp=self.min_disp,
+                min_genes=self.min_genes, min_cells=self.min_cells, log=self.log,
                 standard_scaler=self.standard_scaler, range_scaler=self.range_scaler)
         self.prediction_ds = get_tf_prediction_ds(self.prediction_adata, batch_size=1000)
 
-def load_from_directory(adata, model_filepath, batch_size=64, min_genes_per_cell=200):
+def load_from_directory(adata, model_filepath, batch_size=64, min_genes_per_cell=None):
 ##     model = tf.saved_model.load(os.path.join(model_filepath, MODEL_PATH))
     cell_types = np.load(os.path.join(model_filepath, CELL_TYPES_PATH), allow_pickle=True)
     genes = np.load(os.path.join(model_filepath, GENES_PATH), allow_pickle=True)
@@ -259,12 +222,12 @@ def load_from_directory(adata, model_filepath, batch_size=64, min_genes_per_cell
     clf = joblib.load(os.path.join(model_filepath, CLASSIFIER_PATH))
 
     prediction_dataset = PollockDataset(adata, batch_size=batch_size, dataset_type='prediction',
-            min_genes=min_genes_per_cell, min_cells=None, mito_threshold=None,
-            max_n_genes=None, log=True, cpm=True, min_disp=None, standard_scaler=standard_scaler,
+            min_genes=min_genes_per_cell, min_cells=None,
+            log=True, standard_scaler=standard_scaler,
             range_scaler=range_scaler, genes=genes, cell_type_encoder=encoder,
             cell_types=cell_types)
 
-    latent_dim = summary['model_parameters']['latent_dim'] if 'model_parameters' in summary else 100
+    latent_dim = summary['model_parameters']['latent_dim']
     pollock_model = PollockModel(cell_types, input_shape=len(genes),
             latent_dim=latent_dim,
             model=os.path.join(model_filepath, MODEL_PATH), summary=summary, clf=clf)
@@ -344,13 +307,6 @@ def compute_loss(model, x, alpha=0.01):
     overall_loss = tf.reduce_mean(reconstruction_loss + alpha * kl_loss)
     return overall_loss
 
-## @tf.function
-## def compute_apply_gradients(model, x, optimizer, alpha=.01):
-##     with tf.GradientTape() as tape:
-##         loss = compute_loss(model, x, alpha=alpha)
-##     gradients = tape.gradient(loss, model.trainable_variables)
-##     optimizer.apply_gradients(zip(gradients, model.trainable_variables))
-
 def get_compute_apply_gradients():
     @tf.function
     def cag(model, x, optimizer, alpha=.01):
@@ -395,8 +351,8 @@ class PollockModel(object):
         self.train_accuracies = []
         self.cell_type_train_losses = {c:[] for c in self.class_names}
         self.cell_type_val_losses = {c:[] for c in self.class_names}
-        self.cell_type_train_accuracies = {c:[] for c in self.class_names}
-        self.cell_type_val_accuracies = {c:[] for c in self.class_names}
+        self.cell_type_train_f1 = {c:[] for c in self.class_names}
+        self.cell_type_val_f1 = {c:[] for c in self.class_names}
 
 
 
@@ -425,7 +381,7 @@ class PollockModel(object):
         else:
             X = cell_adata[cell_ids].X
         loss = tf.keras.metrics.Mean()
-        loss(compute_loss(self.model, X, alpha=self.alpha))
+        loss(compute_loss(self.model, tf.convert_to_tensor(X), alpha=self.alpha))
         return loss.result().numpy()
 
     def get_cell_type_accuracy(self, X, y, clf=None):
@@ -441,7 +397,7 @@ class PollockModel(object):
                 target_names=self.class_names, output_dict=True, zero_division=0)
         return clf, report
 
-    def fit(self, pollock_dataset, epochs=10, max_metric_batches=10, metric_epoch_interval=5):
+    def fit(self, pollock_dataset, epochs=10, max_metric_batches=10, metric_epoch_interval=1):
         compute_apply_gradients = get_compute_apply_gradients()
         for epoch in range(1, epochs + 1):
             start_time = time.time()
@@ -462,45 +418,46 @@ class PollockModel(object):
                 for test_x in pollock_dataset.val_ds.take(max_metric_batches):
                     val_loss(compute_loss(self.model, test_x, alpha=self.alpha))
 
-            if epoch - 1 % metric_epoch_interval == 0:
-    
+            if (epoch - 1) % metric_epoch_interval == 0:
                 ## get losses for each cell type
                 ## randomly taking min(100, n_cells) to keep running time down
                 for cell_type in self.class_names:
                     ## do training
-                    cell_adata = pollock_dataset.train_adata[pollock_dataset.train_adata.obs[pollock_dataset.cell_type_key]==cell_type]
+                    cell_adata = pollock_dataset.train_adata[pollock_dataset.train_adata.obs[
+                            pollock_dataset.cell_type_key]==cell_type]
                     self.cell_type_train_losses[cell_type].append(self.get_cell_type_loss(cell_adata))
     
                     ## do validation
-                    cell_adata = pollock_dataset.val_adata[pollock_dataset.val_adata.obs[pollock_dataset.cell_type_key]==cell_type]
+                    cell_adata = pollock_dataset.val_adata[pollock_dataset.val_adata.obs[
+                            pollock_dataset.cell_type_key]==cell_type]
                     self.cell_type_val_losses[cell_type].append(self.get_cell_type_loss(cell_adata))
     
                 ## do accuracies
                 adata, _ = balancedish_training_generator(pollock_dataset.train_adata,
-                        pollock_dataset.cell_type_key, n_per_cell_type=100)
+                        pollock_dataset.cell_type_key, n_per_cell_type=500)
                 y = pollock_dataset.cell_type_encoder.transform(
                         adata.obs[pollock_dataset.cell_type_key].to_numpy().reshape(
                             (-1, 1))).flatten()
                 X = batch_adata(adata, n=pollock_dataset.batch_size)
-                X, y = X[:max_metric_batches], y[:max_metric_batches*pollock_dataset.batch_size]
+##                 X, y = X[:max_metric_batches], y[:max_metric_batches*pollock_dataset.batch_size]
                 clf, report = self.get_cell_type_accuracy(X, y,
                         clf=None)
-                self.train_accuracies.append(report['accuracy'])
+                self.train_accuracies.append(report.get('accuracy', 0.))
                 for cell_type in self.class_names: 
-                    self.cell_type_train_accuracies[cell_type].append(report[cell_type]['f1-score'])
+                    self.cell_type_train_f1[cell_type].append(report[cell_type]['f1-score'])
         
                 adata, _ = balancedish_training_generator(pollock_dataset.val_adata,
-                        pollock_dataset.cell_type_key, n_per_cell_type=100)
+                        pollock_dataset.cell_type_key, n_per_cell_type=500)
                 y = pollock_dataset.cell_type_encoder.transform(
                         adata.obs[pollock_dataset.cell_type_key].to_numpy().reshape(
                             (-1, 1))).flatten()
                 X = batch_adata(adata, n=pollock_dataset.batch_size)
-                X, y = X[:max_metric_batches], y[:max_metric_batches*pollock_dataset.batch_size]
+##                 X, y = X[:max_metric_batches], y[:max_metric_batches*pollock_dataset.batch_size]
                 _, report = self.get_cell_type_accuracy(X, y,
                         clf=clf)
-                self.val_accuracies.append(report['accuracy'])
+                self.val_accuracies.append(report.get('accuracy', 0.))
                 for cell_type in self.class_names: 
-                    self.cell_type_val_accuracies[cell_type].append(report[cell_type]['f1-score'])
+                    self.cell_type_val_f1[cell_type].append(report[cell_type]['f1-score'])
 
             logging.info(f'epoch: {epoch}, train loss: {train_loss.result()}, \
 val loss: {val_loss.result()}') 
@@ -559,14 +516,14 @@ val loss: {val_loss.result()}')
             d = {}
 
         d['history'] = {
-                'train_losses': self.train_losses,
-                'validation_losses': self.val_losses,
-                'train_accuracies': self.train_losses,
-                'validation_accuracies': self.val_losses,
-                'cell_type_train_losses': self.cell_type_train_losses,
-                'cell_type_val_losses': self.cell_type_val_losses,
-                'cell_type_train_accuracies': self.cell_type_train_accuracies,
-                'cell_type_val_accuracies': self.cell_type_val_accuracies,
+                'train_loss': self.train_losses,
+                'validation_loss': self.val_losses,
+                'train_accuracy': self.train_accuracies,
+                'validation_accuracy': self.val_accuracies,
+                'cell_type_train_loss': self.cell_type_train_losses,
+                'cell_type_val_loss': self.cell_type_val_losses,
+                'cell_type_train_f1': self.cell_type_train_f1,
+                'cell_type_val_f1': self.cell_type_val_f1,
                 }
 
         d['model_parameters'] = {
